@@ -1,4 +1,4 @@
-"""Urls for nautobot_plugin_ip_services."""
+"""Urls for nautobot-plugin-ip-services."""
 
 from django.urls import path
 
