@@ -1,4 +1,4 @@
-"""Views for nautobot_plugin_ip_services."""
+"""Views for nautobot-plugin-ip-services."""
 
 from django.shortcuts import get_object_or_404, redirect, render
 from nautobot.ipam.forms import ServiceForm
